"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TarballHttpFetcher = void 0;

var _core = require("@yarnpkg/core");

var _constants = require("./constants");

class TarballHttpFetcher {
  supports(locator, opts) {
    if (!_constants.TARBALL_REGEXP.test(locator.reference)) return false;
    if (_constants.PROTOCOL_REGEXP.test(locator.reference)) return true;
    return false;
  }

  getLocalPath(locator, opts) {
    return null;
  }

  async fetch(locator, opts) {
    const expectedChecksum = opts.checksums.get(locator.locatorHash) || null;
    const [packageFs, releaseFs, checksum] = await opts.cache.fetchPackageFromCache(locator, expectedChecksum, async () => {
      opts.report.reportInfoOnce(_core.MessageName.FETCH_NOT_CACHED, `${_core.structUtils.prettyLocator(opts.project.configuration, locator)} can't be found in the cache and will be fetched from the remote server`);
      return await this.fetchFromNetwork(locator, opts);
    });
    return {
      packageFs,
      releaseFs,
      prefixPath: _core.structUtils.getIdentVendorPath(locator),
      checksum
    };
  }

  async fetchFromNetwork(locator, opts) {
    const sourceBuffer = await _core.httpUtils.get(locator.reference, {
      configuration: opts.project.configuration
    });
    return await _core.tgzUtils.convertToZip(sourceBuffer, {
      stripComponents: 1,
      prefixPath: _core.structUtils.getIdentVendorPath(locator)
    });
  }

}

exports.TarballHttpFetcher = TarballHttpFetcher;